import { type MouseEvent, type ReactNode } from 'react';
type ActionModalProps = {
    isOpen: boolean;
    onClose: VoidFunction;
    heading: string;
    isAcceptDisabled?: boolean;
    children?: ReactNode;
    /** defaults `false` */
    displayCancelButton?: boolean;
    cancelButtonText?: string;
    continueButtonText?: string;
    onAccept: VoidFunction | ((e: MouseEvent<HTMLElement>) => void);
};
/**
 * ActionModal is a basic modal designed for use to alert the user.
 * It has not been designed for forms or advanced usage.
 *
 * ActionModal should be used with the hook useDisclosure, with isOpen and onClose
 * passed as props.
 *
 * ActionModal can be customised with heading and passed any children elements.
 * By default, the cancel button is hidden but can be overridden. The cancel button
 * text can also be provided to override the default of "Cancel".
 *
 * The accept button can be customised by passing in a function to fire when clicked
 * through the onAccept prop and the default text of "Continue" can be overridden as well.
 */
export declare function ActionModal({ isOpen, onClose, onAccept, isAcceptDisabled, heading, children, displayCancelButton, cancelButtonText, continueButtonText, }: ActionModalProps): import("react/jsx-runtime").JSX.Element;
export {};
