import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Modal as BaseModal, Button, HStack, Heading, ModalBody, ModalContent, ModalFooter, ModalHeader, ModalOverlay, } from '@chakra-ui/react';
/**
 * ActionModal is a basic modal designed for use to alert the user.
 * It has not been designed for forms or advanced usage.
 *
 * ActionModal should be used with the hook useDisclosure, with isOpen and onClose
 * passed as props.
 *
 * ActionModal can be customised with heading and passed any children elements.
 * By default, the cancel button is hidden but can be overridden. The cancel button
 * text can also be provided to override the default of "Cancel".
 *
 * The accept button can be customised by passing in a function to fire when clicked
 * through the onAccept prop and the default text of "Continue" can be overridden as well.
 */
export function ActionModal({ isOpen, onClose, onAccept, isAcceptDisabled, heading, children, displayCancelButton = false, cancelButtonText = 'Cancel', continueButtonText = 'Continue', }) {
    return (_jsxs(BaseModal, { isOpen: isOpen, onClose: onClose, size: "lg", children: [_jsx(ModalOverlay, {}), _jsxs(ModalContent, { sx: { borderRadius: '4px' }, children: [_jsx(ModalHeader, { sx: {
                            borderBottom: '1px solid',
                            borderColor: 'border',
                            paddingY: '5',
                        }, children: _jsx(HStack, { spacing: 4, alignItems: "center", children: _jsx(Heading, { children: heading }) }) }), _jsx(ModalBody, { sx: { minHeight: 8, paddingY: '18px' }, fontSize: "sm", children: children }), _jsxs(ModalFooter, { justifyContent: displayCancelButton ? 'space-between' : 'flex-end', sx: { borderTop: '1px solid', borderColor: 'border' }, children: [displayCancelButton && (_jsx(Button, { variant: "outline", w: 140, sx: { textTransform: 'uppercase' }, onClick: onClose, fontSize: "xs", children: cancelButtonText })), _jsx(Button, { variant: "solid", w: 140, sx: { textTransform: 'uppercase' }, onClick: onAccept, isDisabled: isAcceptDisabled, children: continueButtonText })] })] })] }));
}
//# sourceMappingURL=ActionModal.js.map