import { type UseCheckboxProps, type useCheckboxGroup } from '@chakra-ui/react';
import { type ReactNode } from 'react';
export type GetCheckBoxProps = ReturnType<typeof useCheckboxGroup>['getCheckboxProps'];
type InteractableTagProps = {
    label: ReactNode;
    icon?: JSX.Element;
    size?: string;
    checkboxProps: UseCheckboxProps;
    isDisabled?: boolean;
};
/**
 * Renders a button that acts like a checkbox, and looks similar to the Chakra
 * Tag component.
 *
 * Its primary use is as a control in a checkbox group.
 *
 * Can optionally display an icon, and has 2 sizes (change size by passing size='sm')
 *
 * State is handled by the Chakra hook `useCheckboxGroup` like so:
 *
 * @example
 *
 * ```tsx
 * const Tags = () => {
 *   const { value, setValue, getCheckboxProps } = useCheckboxGroup({
 *     defaultValue: ['foo'],
 *   });
 *   // note that you can imperatively `setValue(['foo'])`
 *
 *   return (
 *     <>
 *       <InteractableTag
 *         label="Foo"
 *         checkboxProps={getCheckboxProps({ value: 'foo' })}
 *       />
 *       <InteractableTag
 *         label="Bar"
 *         checkboxProps={getCheckboxProps({ value: 'bar' })}
 *       />
 *       <output>{JSON.stringify(value)}</output>
 *     </>
 *   );
 * }
 * ```
 *
 * @see https://chakra-ui.com/docs/hooks/use-checkbox-group
 * @see https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/checkbox/src/use-checkbox-group.ts
 */
export declare function InteractableTag({ icon, label, size, checkboxProps, isDisabled, }: InteractableTagProps): import("react/jsx-runtime").JSX.Element;
export {};
