import { Button } from '@chakra-ui/react';
import { getThemingArgTypes, } from '@burnsred/utils-storybook';
import { brTheme } from '../../theme';
import { handleClickPlaceholder } from '../../util';
/**
 * Button component is used to trigger an action or event, such as submitting a
 * form, opening a Dialog, canceling an action, or performing a delete
 * operation.
 *
 * By default, the button is rendered with the 'solid' variant and 'md' size.
 *
 * You can pass in a colorScheme in order to change the colors of the button.
 *
 * See https://chakra-ui.com/docs/components/button for more information
 */
const meta = {
    title: 'Components/Atoms/Button',
    component: Button,
    args: {
        children: 'Button Label',
        sx: {},
        onClick: handleClickPlaceholder,
    },
    argTypes: getThemingArgTypes(brTheme, 'Button'),
};
export default meta;
/** This is the default variant when creating a button */
export const SolidMedium = {
    args: {},
};
export const SolidExtraSmall = {
    args: {
        variant: 'solid',
        size: 'xs',
    },
};
export const SolidSmall = {
    args: {
        variant: 'solid',
        size: 'sm',
    },
};
export const SolidLarge = {
    args: {
        variant: 'solid',
        size: 'lg',
    },
};
export const SolidWithColorScheme = {
    args: {
        colorScheme: 'orange',
    },
};
/** Render the button with an outlined appearance */
export const OutlineMedium = {
    args: {
        variant: 'outline',
    },
};
export const OutlineExtraSmall = {
    args: {
        variant: 'outline',
        size: 'xs',
    },
};
export const OutlineSmall = {
    args: {
        variant: 'outline',
        size: 'sm',
    },
};
export const OutlineLarge = {
    args: {
        variant: 'outline',
        size: 'lg',
    },
};
/** Resembles an HTML link */
export const LinkMedium = {
    args: {
        variant: 'link',
    },
};
export const LinkExtraSmall = {
    args: {
        variant: 'link',
        size: 'xs',
    },
};
export const LinkSmall = {
    args: {
        variant: 'link',
        size: 'sm',
    },
};
export const LinkLarge = {
    args: {
        variant: 'link',
        size: 'lg',
    },
};
/** Render without a fill or stroke, but with the proportions of solid & outline */
export const GhostMedium = {
    args: {
        variant: 'ghost',
    },
};
export const GhostExtraSmall = {
    args: {
        variant: 'ghost',
        size: 'xs',
    },
};
export const GhostSmall = {
    args: {
        variant: 'ghost',
        size: 'sm',
    },
};
export const GhostLarge = {
    args: {
        variant: 'ghost',
        size: 'lg',
    },
};
//# sourceMappingURL=Button.stories.js.map