import { type BoxProps, type ColorMode } from '@chakra-ui/react';
type ColorModeBoxProps = BoxProps & {
    colorMode: ColorMode;
};
/**
 * Force children to use a colorMode, working around an inheritance bug:
 *
 * @see Issue https://github.com/chakra-ui/chakra-ui/issues/6916
 *
 * > ...you might want Chakra components to look the same in both light and dark
 * > modes. To achieve this, wrap the component in a LightMode or DarkMode
 * > component. Doing this will override the global colorMode.
 * > https://chakra-ui.com/docs/styled-system/color-mode#forcing-a-specific-mode
 */
export declare const ColorModeBox: ({ colorMode, ...props }: ColorModeBoxProps) => import("react/jsx-runtime").JSX.Element;
/** Force children to use dark mode  */
export declare const DarkModeBox: (props: BoxProps) => import("react/jsx-runtime").JSX.Element;
/** Force children to use light mode  */
export declare const LightModeBox: (props: BoxProps) => import("react/jsx-runtime").JSX.Element;
export {};
