import { jsx as _jsx } from "react/jsx-runtime";
import { Box, DarkMode, LightMode, } from '@chakra-ui/react';
/**
 * Force children to use a colorMode, working around an inheritance bug:
 *
 * @see Issue https://github.com/chakra-ui/chakra-ui/issues/6916
 *
 * > ...you might want Chakra components to look the same in both light and dark
 * > modes. To achieve this, wrap the component in a LightMode or DarkMode
 * > component. Doing this will override the global colorMode.
 * > https://chakra-ui.com/docs/styled-system/color-mode#forcing-a-specific-mode
 */
export const ColorModeBox = ({ colorMode, ...props }) => {
    const ModeComponent = colorMode === 'dark' ? DarkMode : LightMode;
    return (_jsx(ModeComponent, { children: _jsx(Box, { "data-theme": colorMode, bg: "chakra-body-bg", color: "chakra-body-text", ...props }) }));
};
/** Force children to use dark mode  */
export const DarkModeBox = (props) => (_jsx(ColorModeBox, { colorMode: "dark", ...props }));
/** Force children to use light mode  */
export const LightModeBox = (props) => (_jsx(ColorModeBox, { colorMode: "dark", ...props }));
//# sourceMappingURL=ColorModeBox.js.map