import { jsx as _jsx } from "react/jsx-runtime";
import { chakra, forwardRef, useStyleConfig, } from '@chakra-ui/react';
/**
 * Themeable `<form />` element.
 *
 * _This component avoids type errors that occur when attempting
 * `<Box as="form" />`_
 */
export const Form = forwardRef((props, ref) => {
    const { size, variant, ...rest } = props;
    const styles = useStyleConfig('Form', { size, variant });
    /*
    We use `<chakra.form>` rather than `<Box as="form">` to prevent the type error:
    > Type 'FormEvent<HTMLDivElement>' is not assignable to type 'FormEvent<HTMLFormElement>'
  
    https://chakra-ui.com/community/recipes/as-prop#option-1-using-forwardref-from-chakra-uireact
    https://github.com/chakra-ui/chakra-ui/issues/2352
    */
    return _jsx(chakra.form, { ref: ref, __css: styles, ...rest });
});
Form.displayName = 'Form';
//# sourceMappingURL=Form.js.map