import { type LinkProps as ChakraLinkProps } from '@chakra-ui/react';
import { type LinkProps as RouterLinkProps } from 'react-router-dom';
export type LinkProps = Omit<ChakraLinkProps, 'href'> & RouterLinkProps;
/**
 * Themeable Link which wraps react-router's Link.
 *
 * ```tsx
 * <Link to="/">anchor text</Link>
 * ```
 *
 * Note: Our default usage pattern is to link to a client-side route using
 * react-router; in the case you want to link to an external URL, instead:
 *
 * ```tsx
 * import { Link } from '@chakra-ui/react';
 * ```
 *
 * @see https://reactrouter.com/en/main/components/link
 * @see https://chakra-ui.com/docs/components/link/usage#usage-with-routing-library
 */
export declare const Link: (props: LinkProps) => import("react/jsx-runtime").JSX.Element;
/**
 * Deprecated; prefer importing Link
 *
 * Prior to build improvements, importing Link from a consuming app threw the
 * following error:
 *
 * > Cannot destructure property 'basename' of 'k.useContext(...)' as it is null.
 *
 * It seems this had to do with RouterLink requiring to be a child of RouterProvider,
 * which _should_ work like this, but doesn't... If this component is defined within
 * the consuming app, rather than the library, it works as expected.
 *
 * ## Workaround
 *
 * ```tsx
 * import { Link } from '@chakra-ui/react';
 * import { Link as RouterLink } from 'react-router-dom';
 *
 * <Link as={RouterLink} to="#">Anchor</Link>
 * ```
 *
 * @deprecated
 */
export declare const Unsafe_Link: (props: LinkProps) => import("react/jsx-runtime").JSX.Element;
export type Unsafe_LinkProps = LinkProps;
