import { jsx as _jsx } from "react/jsx-runtime";
import { Link as ChakraLink, } from '@chakra-ui/react';
import { Link as RouterLink, } from 'react-router-dom';
/**
 * Themeable Link which wraps react-router's Link.
 *
 * ```tsx
 * <Link to="/">anchor text</Link>
 * ```
 *
 * Note: Our default usage pattern is to link to a client-side route using
 * react-router; in the case you want to link to an external URL, instead:
 *
 * ```tsx
 * import { Link } from '@chakra-ui/react';
 * ```
 *
 * @see https://reactrouter.com/en/main/components/link
 * @see https://chakra-ui.com/docs/components/link/usage#usage-with-routing-library
 */
export const Link = (props) => (_jsx(ChakraLink, { as: RouterLink, ...props }));
/**
 * Deprecated; prefer importing Link
 *
 * Prior to build improvements, importing Link from a consuming app threw the
 * following error:
 *
 * > Cannot destructure property 'basename' of 'k.useContext(...)' as it is null.
 *
 * It seems this had to do with RouterLink requiring to be a child of RouterProvider,
 * which _should_ work like this, but doesn't... If this component is defined within
 * the consuming app, rather than the library, it works as expected.
 *
 * ## Workaround
 *
 * ```tsx
 * import { Link } from '@chakra-ui/react';
 * import { Link as RouterLink } from 'react-router-dom';
 *
 * <Link as={RouterLink} to="#">Anchor</Link>
 * ```
 *
 * @deprecated
 */
export const Unsafe_Link = Link;
//# sourceMappingURL=Link.js.map