import { type Meta, type StoryObj } from '@storybook/react';
import { Link } from '.';
/**
 * Demonstrates _presentation_ of a locally routed Link.
 *
 * Note that our our default usage of this is a styled `RouterLink`,
 * which doesn't render in Storybook without being nested inside
 * a `<Route />`.
 *
 * Note: **Usage of our wrapped `Link` actually requires the `to` prop**,
 * **rather than `href` demonstrated in the stories below.**
 *
 * ```ts
 * import { Link as RouterLink } from 'react-router-dom';
 *
 * // under the hood, renders:
 * <ChakraLink as={RouterLink} {...props} />
 *
 * // usage of our default requires the `to` prop, rather than `href`:
 * <Link to="/relative/route">Anchor text</Link>
 * ```
 */
declare const meta: Meta<typeof Link>;
export default meta;
type Story = StoryObj<typeof Link>;
export declare const Basic: Story;
/**
 * Demonstrates usage of the `_hover` pseudo selector:
 *
 * https://chakra-ui.com/docs/styled-system/style-props#pseudo
 */
export declare const HoverUnderlineDisabled: Story;
