import { getThemingArgTypes, } from '@burnsred/utils-storybook';
import { brTheme } from '../..';
import { Link } from '.';
/**
 * Demonstrates _presentation_ of a locally routed Link.
 *
 * Note that our our default usage of this is a styled `RouterLink`,
 * which doesn't render in Storybook without being nested inside
 * a `<Route />`.
 *
 * Note: **Usage of our wrapped `Link` actually requires the `to` prop**,
 * **rather than `href` demonstrated in the stories below.**
 *
 * ```ts
 * import { Link as RouterLink } from 'react-router-dom';
 *
 * // under the hood, renders:
 * <ChakraLink as={RouterLink} {...props} />
 *
 * // usage of our default requires the `to` prop, rather than `href`:
 * <Link to="/relative/route">Anchor text</Link>
 * ```
 */
const meta = {
    title: 'Components/Atoms/Link',
    component: Link,
    args: {
        children: 'Anchor text',
        to: '#',
    },
    argTypes: getThemingArgTypes(brTheme, 'Link'),
};
export default meta;
export const Basic = {
    args: {},
};
/**
 * Demonstrates usage of the `_hover` pseudo selector:
 *
 * https://chakra-ui.com/docs/styled-system/style-props#pseudo
 */
export const HoverUnderlineDisabled = {
    args: {
        sx: {
            _hover: { textDecoration: 'none' },
        },
    },
};
//# sourceMappingURL=Link.stories.js.map