import { jsx as _jsx } from "react/jsx-runtime";
import { Box, Button, Menu as ChakraMenu, MenuButton as ChakraMenuButton, } from '@chakra-ui/react';
import { MdChevronRight } from 'react-icons/md';
// re-export all Menu components so they can be imported from a single location
export { MenuItem, MenuList, } from '@chakra-ui/react';
/**
 * Chakra Menu component with a workaround for a Popper.js warning when Menu is used inside Stack:
 *
 * [Menu component causes warning: "Popper: CSS "margin" styles cannot be used to apply padding..." Issue #3440 · chakra-ui/chakra-ui](https://github.com/chakra-ui/chakra-ui/issues/3440)
 *
 * @see https://chakra-ui.com/docs/components/menu/usage
 */
export const Menu = ({ sx, ...props }) => (_jsx(Box, { sx: sx, children: _jsx(ChakraMenu, { ...props }) }));
/**
 * These styles are tightly coupled with the choice of icon, so declare them
 * locally, rather than as a Button variant.
 *
 * Rotation amount assumes we're using MdChevronRight
 * (requires initial rotation of 90deg).
 */
const rotatingIconStyles = {
    '.chakra-button__icon': {
        transition: 'all 0.25s ease-in-out 0s',
        transform: 'rotate(90deg)',
    },
    _expanded: {
        '.chakra-button__icon': {
            transform: 'rotate(-90deg)',
        },
    },
};
/**
 * Wraps Chakra.MenuButton with our own defaults
 *
 * (which can't be accommodated merely with variants due to `as`, `rightIcon`, etc)
 */
export const MenuButton = ({ children, sx, ...props }) => (_jsx(ChakraMenuButton, { as: Button, sx: {
        ...rotatingIconStyles,
        ...sx,
    }, rightIcon: _jsx(MdChevronRight, {}), ...props, children: children }));
//# sourceMappingURL=Menu.js.map