import { jsx as _jsx } from "react/jsx-runtime";
import { chakra, forwardRef, useStyleConfig, } from '@chakra-ui/react';
/**
 * Renders a wrapper with minHeight 100vh
 *
 * ```tsx
 * <FullHeight> width: 100% </FullHeight>
 * <FullHeight variant="container" size="lg"> mimics Container </FullHeight>
 * ```
 */
export const FullHeight = forwardRef((props, ref) => {
    const { size, variant, ...rest } = props;
    const styles = useStyleConfig('FullHeight', { size, variant });
    return (_jsx(chakra.div, { className: "FullHeight", ref: ref, __css: styles, ...rest }));
});
FullHeight.displayName = 'FullHeight';
export default FullHeight;
//# sourceMappingURL=FullHeight.js.map