import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { AccordionButton, AccordionIcon, AccordionItem, AccordionPanel, Card, CardBody, CardHeader, Grid, Heading, } from '@chakra-ui/react';
/**
 *  FieldGroup that composes Card, Accordion, and Grid to allow declarative
 *  layout of children by specifying how many columns each input should occupy.
 *
 *  ```tsx
 *  <Accordion allowToggle>
 *   <AccordionFieldGroup {...args}>
 *     <InputField label="First name" />
 *     <InputField label="First name" />
 *     <InputField label="Contact number" />
 *   </AccordionFieldGroup>
 * </Accordion>
 *
 * If the AccordionItem contains Popper elements (eg DatePicker), then pass `isDocked`
 * to prevent the Popper item get covered by the card below.
 *  ```
 */
export const AccordionFieldGroup = ({ noGrid = false, title, children, templateColumns = 'repeat(3, 1fr)', gridGap = '8', rowGap = '4', isDocked = false, }) => {
    return (_jsxs(Card, { variant: "formCard", as: AccordionItem, 
        // Docked z-index so the Popper elements (eg DatePicker) are not covered by other cards
        zIndex: isDocked ? 'docked' : '', children: [_jsxs(CardHeader, { as: AccordionButton, role: "heading", children: [_jsx(Heading, { size: "sm", children: title }), _jsx(AccordionIcon, {})] }), _jsx(CardBody, { as: AccordionPanel, children: !noGrid ? (_jsx(Grid, { templateColumns: templateColumns, gap: gridGap, rowGap: rowGap, children: children })) : (_jsxs(_Fragment, { children: [" ", children, " "] })) })] }));
};
//# sourceMappingURL=AccordionFieldGroup.js.map