import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Accordion } from '@chakra-ui/react';
import { Form, InputField } from '../..';
import { AccordionFieldGroup } from '.';
/**
 *  FieldGroup that composes Card, Accordion, and Grid to allow declarative
 *  layout of children by specifying how many columns each input should occupy.
 *
 *  ```tsx
 *  <Form as={Accordion} allowToggle>
 *   <AccordionFieldGroup {...args}>
 *     <InputField label="First name" />
 *     <InputField label="First name" />
 *     <InputField label="Contact number" />
 *   </AccordionFieldGroup>
 * </Form>
 *  ```
 */
const meta = {
    title: 'Components/widgets/AccordionFieldGroup',
    component: AccordionFieldGroup,
    args: {
        title: 'AccordionFieldGroup label',
        templateColumns: 'repeat(3, 1fr)',
        gridGap: '8',
        rowGap: '4',
    },
    argTypes: {
        // ...getThemingArgTypes(brTheme as SimpleTheme, 'Card'),
        title: { control: 'text' },
        templateColumns: { control: 'text' },
        gridGap: { control: 'text' },
        rowGap: { control: 'text' },
    },
};
export default meta;
export const Initial = {
    render: (args) => (_jsx(Form, { as: Accordion, allowToggle: true, defaultIndex: [0], children: _jsxs(AccordionFieldGroup, { ...args, children: [_jsx(InputField, { label: "First name" }), _jsx(InputField, { label: "First name" }), _jsx(InputField, { label: "Contact number" }), _jsx(InputField, { label: "Street Number" }), _jsx(InputField, { label: "Street" }), _jsx(InputField, { label: "Postcode" })] }) })),
};
export const AsymmetricalFields = {
    render: (args) => (_jsx(Form, { as: Accordion, children: _jsxs(AccordionFieldGroup, { ...args, templateColumns: "10", children: [_jsx(InputField, { colSpan: 10, label: "No fixed address", type: "text" }), _jsx(InputField, { colSpan: 5, label: "Address", type: "text" }), _jsx(InputField, { colSpan: 3, label: "Suburb", type: "text" }), _jsx(InputField, { colSpan: 2, label: "Postcode", type: "text" }), _jsx(InputField, { colSpan: 2, label: "State", type: "text" }), _jsx(InputField, { colSpan: 3, label: "Contact number", type: "text" }), _jsx(InputField, { colSpan: 5, label: "Email", type: "email" })] }) })),
};
//# sourceMappingURL=AccordionFieldGroup.stories.js.map