import { type Meta, type StoryObj } from '@storybook/react';
import { Autocomplete } from '.';
/**
 * https://chakra-ui.com/docs/components/autocomplete
 *
 * The upstream library has many examples, (only some of which have been replicated below):
 *
 * - https://codesandbox.io/s/chakra-react-select-sizes-w9sf8e?file=/example.js:1236-1440
 * - https://codesandbox.io/s/chakra-react-select-color-schemes-c38jlo?file=/example.js:1424-1547
 * - https://codesandbox.io/s/chakra-react-select-tag-variants-w31gnt?file=/example.js:1378-1392
 * - https://codesandbox.io/s/chakra-react-select-invalid-disabled-0hyl8l?file=/example.js
 * - https://codesandbox.io/s/chakra-react-select-border-colors-gjo4zd?file=/example.js
 * - https://codesandbox.io/s/chakra-react-select-usebasicstyles-jjnqsd?file=/example.js
 * - https://codesandbox.io/s/chakra-react-select-border-selectedoptionstyle-yxkcos?file=/example.js
 * - https://codesandbox.io/s/chakra-react-select-border-selectedoptioncolor-yyd321?file=/example.js:963-1040
 * - https://codesandbox.io/s/chakra-react-select-variant-5cf755?file=/example.js
 * - https://codesandbox.io/s/chakra-react-select-hasstickygroupheaders-wg39g?file=/docs/data.js
 * - https://codesandbox.io/s/chakra-react-select-border-selectedoptionstyle-yxkcos?file=/example.js
 */
declare const meta: Meta<typeof Autocomplete>;
export default meta;
type Story = StoryObj<typeof Autocomplete>;
/** https://codesandbox.io/s/chakra-react-select-border-selectedoptionstyle-yxkcos?file=/example.js:723-736 */
export declare const Primary: Story;
/**
 * Demonstrates use of the `onChange` callback to set state,
 * and transforming options to the required format.
 */
export declare const WithParentState: Story;
/**
 * These extend our defaults in Autocomplete.styles.tsx
 *
 * See https://github.com/csandman/chakra-react-select#chakrastyles
 * for a complete list of styleable elements.
 *
 * ```ts
 * <Autocomplete
 *   chakraStyles: {
 *     control: (prev) => ({
 *       ...prev,
 *       bg: 'purple.200',
 *     }),
 *
 *     // uses theme styles for Chakra's CloseButton
 *     clearIndicator: (prev) => ({
 *       ...prev,
 *       color: 'error',
 *       _hover: {
 *         bg: 'error',
 *
 *         '> svg': {
 *           color: 'white',
 *         },
 *       },
 *     }),
 *   }
 * />
 * ```
 */
export declare const CustomStyles: Story;
/** Display a Check icon to the left of the selected option */
export declare const SelectOptionCheck: Story;
/**
 * Medium Select `size="md"`
 */
export declare const Sizes: Story;
/**
 * Sets a colorScheme for each selected option
 */
export declare const ColouredOptions: Story;
/**
 * Use a variant to display selected Tags
 *
 * It's also possible to set each tag to display using a separate variant:
 * [CodeSandBox](https://codesandbox.io/s/chakra-react-select-tag-variants-w31gnt?file=/example.js)
 */
export declare const OptionsTagVariants: Story;
/**
 * When disabled at the FormControl level, the FormLabel is blurred along with the select
 */
export declare const DisabledFromFormGroup: Story;
/**
 * With selectedOptionColor="teal"
 */
export declare const SelectedColorOption: Story;
/**
 * _(countries options have been truncated)_
 */
export declare const StickyOptionHeaders: Story;
/**
 *
 */
export declare const _Variants: Story;
