import { jsx as _jsx } from "react/jsx-runtime";
import { Grid } from '@chakra-ui/react';
/**
 *  FieldGroup that wraps Grid to allow declarative layout of children by
 *  specifying how many columns each input should occupy.
 *
 *  ```tsx
 * <FieldGroup templateColumns={3}>
 *   <InputField label="First name" />
 *   <InputField label="First name" />
 *   <InputField label="Contact number" />
 * </FieldGroup>
 *
 * <FieldGroup templateColumns={12}>
 *   <InputField name="short" colSpan={2} />
 *   <InputField name="long" colsSpan={10} />
 * </FieldGroup>
 *  ```
 *
 * @see https://chakra-ui.com/docs/components/grid/usage
 */
export const FieldGroup = ({ children, templateColumns = '12', gridGap = '4', rowGap = '8', width = 'full', }) => (_jsx(Grid, { templateColumns: templateColumns, gap: gridGap, rowGap: rowGap, width: width, children: children }));
//# sourceMappingURL=FieldGroup.js.map