import { type ReactNode } from 'react';
import { type Accept } from 'react-dropzone';
type FilePickerProps = {
    /** Disables the FilePicker - defaults to false */
    isDisabled?: boolean;
    /** A ReactNode containing the message to be rendered
     * in the middle of the FilePicker. Defaults to
     * 'Drag and drop files here or click to select files.' with
     * blue font for 'click to select files.'
     */
    message?: ReactNode;
    /** Sets the number of files allowed to be uploaded - defaults to one file. */
    fileLimit?: number;
    /** Sets the accepted file types for the component. Defaults to:
     * @example
     * 'image/*': ['.png', '.gif', '.jpg', '.jpeg'],
     * 'application/*': ['.doc', '.docx', '.xls', '.xlsx', '.ppt', '.pptx', '.pdf'],
     * 'text/*': ['.txt'],
     * 'audio/*': ['.mp3', '.mp4', '.wav'],
     * 'video/*': ['.mpg', '.mov', '.wmv'],
     */
    fileTypeRestrictions?: Accept;
    /** Sets the maxFile for validating the selected file. Defaults to 20971520 bytes (20MB) */
    fileSizeRestriction?: number;
    /** Sets whether to render the FileList below the dropzone. Defaults to true. */
    showFileList?: boolean;
};
/**
 * FilePicker renders a 'drag and drop' zone file selector. The component acts as a zone
 * while also allowing users to select the message to open the OS File Browser.
 *
 * The drop zone renders a single standard html file input field, which has a property `files`
 * When files are dropped on the drop zone, then synchronous local validation occurs, and
 * each file is displayed under the widget with it's validation status. If the file is accepted,
 * it is appended to the file input. Rejected files are not appended to the file input.
 *
 * @see https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input/file
 */
export declare const FilePicker: ({ isDisabled, fileLimit, message, fileTypeRestrictions, showFileList, fileSizeRestriction, }: FilePickerProps) => import("react/jsx-runtime").JSX.Element;
export {};
