import { jsx as _jsx } from "react/jsx-runtime";
import { FilePicker } from './FilePicker';
import { fireEvent, render, screen } from '../../../test';
// temporarily silence logs until component is wired up, and TODO logs removed
console.log = vi.fn();
describe('FilePicker Render Tests', () => {
    test('FilePicker should render with default message', async () => {
        render(_jsx(FilePicker, {}));
        expect(await screen.getByTestId('dropzone-container').textContent).toBe('Drag and drop files here or click to select files.');
    });
    test('FilePicker should render with custom message', async () => {
        render(_jsx(FilePicker, { message: "Custom Message" }));
        expect(await screen.getByTestId('dropzone-container').textContent).toBe('Custom Message');
    });
});
describe('FilePicker Validation Tests', () => {
    test('FilePicker should reject disallowed filetype', async () => {
        render(_jsx(FilePicker, { fileTypeRestrictions: { 'plain/text': ['.txt'] } }));
        const inputEl = screen.getByTestId('dropzone-input');
        const file = new File(['file'], 'ping.json', {
            type: 'application/json',
        });
        Object.defineProperty(inputEl, 'files', {
            value: [file],
        });
        fireEvent.drop(inputEl);
        expect(await screen.findByText('The file type you selected is not allowed.')).toBeInTheDocument();
    });
    test('FilePicker should reject disallowed filesize', async () => {
        render(_jsx(FilePicker, { fileTypeRestrictions: { 'plain/text': ['.txt'] } }));
        const inputEl = screen.getByTestId('dropzone-input');
        const file = new File(['file'], 'ping.json', {
            type: 'application/json',
        });
        Object.defineProperty(file, 'size', { value: 22020096 });
        Object.defineProperty(inputEl, 'files', {
            value: [file],
        });
        fireEvent.drop(inputEl);
        expect(await screen.findByText('The file you selected is too large.')).toBeInTheDocument();
    });
    /*test('FilePicker should render accepted file name', async () => {
      render(<FilePicker fileTypeRestrictions={{ 'text/plain': ['.txt'] }} />);
      const inputEl: HTMLInputElement = screen.getByTestId('dropzone-input');
      const file = new File(['file'], 'ping.txt', {
        type: 'text/plain',
      });
      Object.defineProperty(inputEl, 'files', {
        value: [file],
      });
      fireEvent.drop(inputEl);
      expect(await screen.findByText(file.name)).toBeInTheDocument();
      expect(inputEl.files).toHaveLength(1);
    });*/
});
//# sourceMappingURL=FilePicker.test.js.map