import { jsx as _jsx } from "react/jsx-runtime";
import { Input } from '@chakra-ui/react';
import { useMemo, useRef } from 'react';
/**
 * Use this as a template for overriding `inputComponent`
 *
 * Your input component must pass `ref={props.inputRef}`:
 *
 * ```tsx
 * const CustomInput = ({ inputRef, ...props }: OverridableInputProps) => (
 *   <InputGroup>
 *     <Input inputRef={inputRef} {...props} />
 *     <InputRightAddon
 *       onClick={() => inputRef?.current?.focus()}
 *       layerStyle="hoverPointer"
 *     >
 *       {'🚀'}
 *     </InputRightAddon>
 *   </InputGroup>
 * );
 * ```
 */
const DefaultInput = ({ inputRef, ...props }) => (_jsx(Input, { ...props, ref: inputRef }));
/**
 * @see https://chakra-ui.com/docs/components/input
 */
export function WidgetInput({ 
// namespace = 'component_widgetInput',
inputComponent = DefaultInput, inputRef, ...props }) {
    // REVIEW use of react-intl
    /** Used if the parent does not pass inputRef */
    const defaultInputRef = useRef(null);
    // TODO wire up to entity library
    // const enhancedProps = useEnhanceProps(props, { inputComponentProps: { ref } });
    // eslint-disable-next-line react-hooks/exhaustive-deps
    const InputComponent = useMemo(() => inputComponent, []);
    return _jsx(InputComponent, { ...props, inputRef: inputRef ?? defaultInputRef });
}
//# sourceMappingURL=Input.js.map