import { type Meta, type StoryObj } from '@storybook/react';
import { WidgetInput as Input } from '.';
/**
 * https://chakra-ui.com/docs/components/input
 */
declare const meta: Meta<typeof Input>;
export default meta;
type Story = StoryObj<typeof Input>;
export declare const Primary: Story;
/**
 * ```tsx
 * const StyledInput = (props: OverridableInputProps) => (
 *   <Input sx={{ bg: 'purple.100' }} {...props} />
 * );
 * <StyledInput />
 * ```
 */
export declare const SidecarInput: Story;
/**
 * ```tsx
 * <Input sx={{ bg: 'purple.100' }} />
 * ```
 */
export declare const WithSx: Story;
/**
 * https://chakra-ui.com/docs/components/input#left-and-right-addons
 */
export declare const WithLeftAddon: Story;
/**
 * When you need to use a [ref](https://reactjs.org/docs/hooks-reference.html#useref),
 * pass it to `Input` as `inputRef`:
 *
 * ```tsx
 * <Input inputRef={myRef} {...props} />
 * ```
 */
export declare const ClickableIcon: Story;
/**
 * A custom `inputComponent` must pass `ref={inputRef}`:
 *
 * ```tsx
 * import { Input as ChakraInput } from '@chakra-ui/react';
 *
 * const CustomInput = ({ inputRef, ...props }: OverridableInputProps) => (
 *   <Box sx={{ width: 'full', background: 'purple.100' }}>
 *     <ChakraInput
 *       variant="outline"
 *       placeholder="phone number"
 *       ref={inputRef}
 *       {...props}
 *     />
 *   </Box>
 * );
 * ```
 *
 * See also [Pattern for passing typed override components](http://localhost:6006/?path=/docs/spike-override-components--docs)
 */
export declare const CustomInputComponent: Story;
/**
 * A custom `inputComponent` must pass `ref={inputRef}`:
 *
 * ```tsx
 * import { Input as ChakraInput, InputGroup, InputRightAddon } from '@chakra-ui/react';
 *
 * const CustomInputGroup = ({ inputRef, ...props }: OverridableInputProps) => (
 *   <InputGroup>
 *     <ChakraInput ref={inputRef} {...props} />
 *     <InputRightAddon
 *       onClick={() => void inputRef?.current?.focus()}
 *       layerStyle="hoverPointer"
 *     >
 *       {'🚀'}
 *     </InputRightAddon>
 *   </InputGroup>
 * );
 * ```
 *
 * A default `inputRef` will be created and passed to `inputComponent` if `props.inputRef` is not passed.
 */
export declare const CustomInputComponentProper: Story;
