import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/* eslint-disable react-hooks/rules-of-hooks */
import { Box, Input as ChakraInput, Icon, InputGroup, InputLeftAddon, InputRightAddon, } from '@chakra-ui/react';
import { useRef, useState, } from 'react';
import { MdOutlinePhoneEnabled } from 'react-icons/md';
import { getThemingArgTypes, } from '@burnsred/utils-storybook';
import { brTheme } from '../../../theme';
import { handleChangePlaceholder } from '../../../util';
import { WidgetInput as Input } from '.';
/**
 * https://chakra-ui.com/docs/components/input
 */
const meta = {
    title: 'Components/Widgets/Input',
    component: Input,
    args: {
        defaultValue: '',
        onChange: handleChangePlaceholder,
    },
    argTypes: {
        namespace: { control: 'text' },
        ...getThemingArgTypes(brTheme, 'Input'),
    },
};
export default meta;
export const Primary = {
    args: {},
};
const StyledInput = (props) => (_jsx(Input, { sx: { bg: 'purple.100' }, ...props }));
/**
 * ```tsx
 * const StyledInput = (props: OverridableInputProps) => (
 *   <Input sx={{ bg: 'purple.100' }} {...props} />
 * );
 * <StyledInput />
 * ```
 */
export const SidecarInput = {
    args: {},
    render: () => _jsx(StyledInput, {}),
};
/**
 * ```tsx
 * <Input sx={{ bg: 'purple.100' }} />
 * ```
 */
export const WithSx = {
    args: {},
    render: () => _jsx(Input, { sx: { bg: 'purple.100' } }),
};
/**
 * https://chakra-ui.com/docs/components/input#left-and-right-addons
 */
export const WithLeftAddon = {
    args: {},
    render: () => (_jsxs(InputGroup, { children: [_jsx(InputLeftAddon, { children: "+61" }), _jsx(Input, { type: "tel", placeholder: "phone number" })] })),
};
/**
 * When you need to use a [ref](https://reactjs.org/docs/hooks-reference.html#useref),
 * pass it to `Input` as `inputRef`:
 *
 * ```tsx
 * <Input inputRef={myRef} {...props} />
 * ```
 */
export const ClickableIcon = {
    args: {},
    render: () => {
        const [value, setValue] = useState('');
        const myRef = useRef(null);
        const handleChange = (event) => void setValue(event.target.value);
        const handleClick = () => void myRef?.current?.focus();
        return (_jsxs(InputGroup, { children: [_jsx(Input, { type: "tel", placeholder: "phone number", inputRef: myRef, value: value, onChange: handleChange }), _jsx(InputRightAddon, { onClick: handleClick, layerStyle: "hoverPointer", children: _jsx(Icon, { as: MdOutlinePhoneEnabled }) })] }));
    },
};
const CustomInput = ({ inputRef, ...props }) => (_jsx(Box, { sx: { width: 'full', background: 'purple.100' }, children: _jsx(ChakraInput, { placeholder: "Custom Input", variant: "outline", ref: inputRef, ...props }) }));
/**
 * A custom `inputComponent` must pass `ref={inputRef}`:
 *
 * ```tsx
 * import { Input as ChakraInput } from '@chakra-ui/react';
 *
 * const CustomInput = ({ inputRef, ...props }: OverridableInputProps) => (
 *   <Box sx={{ width: 'full', background: 'purple.100' }}>
 *     <ChakraInput
 *       variant="outline"
 *       placeholder="phone number"
 *       ref={inputRef}
 *       {...props}
 *     />
 *   </Box>
 * );
 * ```
 *
 * See also [Pattern for passing typed override components](http://localhost:6006/?path=/docs/spike-override-components--docs)
 */
export const CustomInputComponent = {
    args: {},
    render: () => {
        const [value, setValue] = useState('');
        const inputRef = useRef(null);
        const handleChange = (event) => void setValue(event.target.value);
        const handleClick = () => void inputRef?.current?.focus();
        // render in an InputGroup to demonstrate passing of inputRef
        return (_jsxs(InputGroup, { children: [_jsx(Input, { type: "tel", inputRef: inputRef, inputComponent: CustomInput, value: value, onChange: handleChange }), _jsx(InputRightAddon, { onClick: handleClick, layerStyle: "hoverPointer", children: _jsx(Icon, { as: MdOutlinePhoneEnabled }) })] }));
    },
};
const CustomInputGroup = ({ inputRef, ...props }) => (_jsxs(InputGroup, { children: [_jsx(ChakraInput, { ref: inputRef, ...props }), _jsx(InputRightAddon
        // @ts-expect-error Property 'current' does not exist on type '(instance: HTMLInputElement | null) => void'
        , { 
            // @ts-expect-error Property 'current' does not exist on type '(instance: HTMLInputElement | null) => void'
            onClick: () => void inputRef?.current?.focus(), layerStyle: "hoverPointer", children: '🚀' })] }));
/**
 * A custom `inputComponent` must pass `ref={inputRef}`:
 *
 * ```tsx
 * import { Input as ChakraInput, InputGroup, InputRightAddon } from '@chakra-ui/react';
 *
 * const CustomInputGroup = ({ inputRef, ...props }: OverridableInputProps) => (
 *   <InputGroup>
 *     <ChakraInput ref={inputRef} {...props} />
 *     <InputRightAddon
 *       onClick={() => void inputRef?.current?.focus()}
 *       layerStyle="hoverPointer"
 *     >
 *       {'🚀'}
 *     </InputRightAddon>
 *   </InputGroup>
 * );
 * ```
 *
 * A default `inputRef` will be created and passed to `inputComponent` if `props.inputRef` is not passed.
 */
export const CustomInputComponentProper = {
    args: {},
    render: () => {
        const [value, setValue] = useState('');
        const handleChange = (event) => void setValue(event.target.value);
        return (_jsx(Input
        // no inputRef required here unless you need it
        , { 
            // no inputRef required here unless you need it
            value: value, onChange: handleChange, inputComponent: CustomInputGroup }));
    },
};
//# sourceMappingURL=Input.stories.js.map