import { jsx as _jsx } from "react/jsx-runtime";
import { Icon } from '@chakra-ui/react';
import { MdArrowDropDownCircle } from 'react-icons/md';
import { getThemingArgTypes, } from '@burnsred/utils-storybook';
import { brTheme } from '../../../theme';
import { WidgetSelect as Select } from '.';
const options = [
    _jsx("option", { value: "a", children: "Alpha" }, "a"),
    _jsx("option", { value: "b", children: "Beta" }, "b"),
    _jsx("option", { value: "g", children: "Gamma" }, "g"),
];
/**
 * https://chakra-ui.com/docs/components/select
 */
const meta = {
    title: 'Components/Widgets/Select',
    component: Select,
    args: {
        placeholder: 'Placeholder',
        children: options,
    },
    argTypes: {
        namespace: { control: 'text' },
        // FIXME why are styleProps spammed to the args table?
        // The same Story config without a component not re-exporting Select works properly
        ...getThemingArgTypes(brTheme, 'SelectField'),
    },
};
export default meta;
export const Primary = {
    args: {
        defaultValue: 'a',
    },
};
/** The value for `placeholder` is added as the first `option` */
export const NoOptions = {
    args: {
        ...Primary.args,
        defaultValue: '',
    },
};
/**
 * Use a custom icon for the Select
 *
 * You can rotate an icon by passing eg:
 *
 * ```tsx
 * <Icon as={MdArrowDropDownCircle} sx={{ transform: 'rotate(360deg)' }} />
 * ```
 */
export const CustomIcon = {
    args: {
        ...Primary.args,
        icon: (_jsx(Icon, { as: MdArrowDropDownCircle, sx: { transform: 'rotate(360deg)' } })),
    },
};
//# sourceMappingURL=Select.stories.js.map