type SwitchOption = {
    value: string;
    label: string;
};
type Props = {
    /**
     * Array of SwitchOptions used to render the switch.
     */
    options: SwitchOption[];
    /**
     * Sets the initialValue of the switch. Provided string must match a value provided in the options array.
     */
    initialValue?: string;
    /**
     * Disables the center option of the three-way switch.
     */
    unsetEnabled: boolean;
    /**
     * Makes the entire switch readonly (disabled)
     * defaults to false
     */
    isReadonly?: boolean;
};
/**
 * ThreeWaySwitch component is a variation of the standard switch input,
 * but allows for three states rather than just two.
 *
 * Generally, this is true, false and unset. The values and labels are rendered
 * from an array of objects provided in the options prop.
 *
 * Three options must be passed in the options props otherwise this component will
 * throw an error and render blank.
 *
 * If an initialValue is provided, it must match a corresponding value in the
 * options array otherwise this component will throw an error and render blank.
 *
 */
export declare function ThreeWaySwitch({ options, initialValue, unsetEnabled, isReadonly, }: Props): import("react/jsx-runtime").JSX.Element;
export {};
