import { jsxs as _jsxs, Fragment as _Fragment, jsx as _jsx } from "react/jsx-runtime";
import { useState } from 'react';
import { Switch, SwitchLabel, SwitchRadio, SwitchSelection, } from './ThreeWaySwitch.styles';
const ClickableLabel = ({ children, currentIndex, label, onChange, checked, value, isDisabled = false, ...rest }) => (_jsxs(SwitchLabel, { onClick: (e) => (!isDisabled ? onChange(value) : e.preventDefault()), checked: checked, currentIndex: currentIndex, ...rest, children: [label, children] }));
/**
 * ThreeWaySwitch component is a variation of the standard switch input,
 * but allows for three states rather than just two.
 *
 * Generally, this is true, false and unset. The values and labels are rendered
 * from an array of objects provided in the options prop.
 *
 * Three options must be passed in the options props otherwise this component will
 * throw an error and render blank.
 *
 * If an initialValue is provided, it must match a corresponding value in the
 * options array otherwise this component will throw an error and render blank.
 *
 */
export function ThreeWaySwitch({ options, initialValue, unsetEnabled, isReadonly = false, }) {
    const [switchState, setSwitchState] = useState(initialValue);
    const currentIndex = options.findIndex((option) => {
        return option.value === switchState;
    });
    if (options.length < 3) {
        console.error('Three options are expected for this ThreeWaySwitch');
        return _jsx(_Fragment, {});
    }
    if (currentIndex < 0) {
        console.error('Provided initialValue does not exist in values array.');
        return _jsx(_Fragment, {});
    }
    return (_jsxs(Switch, { currentIndex: currentIndex, children: [_jsx(ClickableLabel, { label: options[0].label, value: options[0].value, onChange: setSwitchState, checked: switchState === options[0].value, currentIndex: currentIndex, isDisabled: isReadonly, children: _jsx(SwitchRadio, { checked: switchState === options[0].value }) }), _jsx(ClickableLabel, { label: options[1].label, value: options[1].value, onChange: setSwitchState, checked: switchState === options[1].value, currentIndex: currentIndex, "aria-label": options[1].label ?? 'Label Not Set', isDisabled: !unsetEnabled || isReadonly, children: _jsx(SwitchRadio, { checked: switchState === options[1].value }) }), _jsx(ClickableLabel, { label: options[2].label, value: options[2].value, onChange: setSwitchState, checked: switchState === options[2].value, currentIndex: currentIndex, isDisabled: isReadonly, children: _jsx(SwitchRadio, { checked: switchState === options[2].value }) }), _jsx(SwitchSelection, { currentIndex: currentIndex })] }));
}
//# sourceMappingURL=ThreeWaySwitch.js.map