/**
> If there is a __mocks__ folder alongside a file that you are mocking, and the
> factory is not provided, Vitest will try to find a file with the same name in
> the __mocks__ subfolder and use it as an actual module. If you are mocking a
> dependency, Vitest will try to find a __mocks__ folder in the root of the
> project (default is process.cwd()).
> ...
> If there is no __mocks__ folder or a factory provided, Vitest will import the
> original module and auto-mock all its exports. For the rules applied, see
> algorithm.
@see https://vitest.dev/api/vi.html#vi-mock


- https://vitest.dev/guide/mocking.html#modules
- https://vitest.dev/api/mock.html
*/
/** Increments the number passed */
export declare const increment: (num: number) => number;
/** Increments the number passed */
export declare const decrement: (num: number) => number;
/**
 * > If you are mocking a module with default export, you will need to provide a
 * > default key within the returned factory function object:
 *
 * ```tsx
 * vi.mock('./path/to/module.js', () => {
 *   return {
 *     default: { myDefaultKey: vi.fn() },
 *     namedExport: vi.fn(),
 *     // etc...
 *   }
 * })
 * ```
 */
export default function (arg: unknown): unknown;
