import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
// https://testing-library.com/docs/example-react-router/#reducing-boilerplate
import { Link, MemoryRouter, Route, Routes, useNavigate, } from 'react-router-dom';
import { Placeholder } from '../..';
import { LocationDisplay, render, renderWithRouter, screen } from '../../test';
const ComponentWithUseReactRouterHook = () => {
    const navigate = useNavigate();
    return (_jsx("button", { onClick: () => navigate('/another-route'), children: "Some Button" }));
};
test('rendering a component that requires Router context', async () => {
    // Error: useNavigate() may be used only in the context of a <Router> component.
    // render(<ComponentWithUseReactRouterHook />);
    renderWithRouter(_jsx(ComponentWithUseReactRouterHook, {}));
    expect(screen.getByRole('button')).toBeInTheDocument();
});
const TestApp = () => {
    const navigate = useNavigate();
    /** https://reactrouter.com/en/main/upgrading/v5#use-usenavigate-instead-of-usehistory */
    const handleBack = () => void navigate(-1);
    return (_jsxs("div", { children: [_jsx(Link, { to: "/", children: "Home" }), _jsx(Link, { to: "/about", children: "About" }), _jsx("button", { onClick: handleBack, children: "Back" }), _jsxs(Routes, { children: [_jsx(Route, { path: "/", element: _jsx(Placeholder, { children: "Home Page" }) }), _jsx(Route, { path: "/about", element: _jsx(Placeholder, { children: "About Page" }) }), _jsx(Route, { path: "*", element: _jsx(Placeholder, { children: "404 Page" }) })] }), _jsx(LocationDisplay, {})] }));
};
test('full test app rendering / navigating', async () => {
    const route = '/something-that-does-not-match';
    const { user } = renderWithRouter(_jsx(TestApp, {}), { route });
    expect(screen.getByText(/404 Page/i)).toBeInTheDocument();
    const locationDisplay = screen.getByTestId('location-display');
    expect(locationDisplay).toHaveTextContent(route);
    await user.click(screen.getByRole('link', { name: 'About' }));
    expect(screen.getByText(/About Page/i)).toBeInTheDocument();
    expect(locationDisplay).toHaveTextContent('/about');
});
test('rendering a component that uses useLocation', () => {
    const route = '/some-route';
    renderWithRouter(_jsx(LocationDisplay, {}), { route });
    expect(screen.getByTestId('location-display')).toHaveTextContent(route);
});
test('use <MemoryRouter> when you want to manually control the history', async () => {
    // use <MemoryRouter> when you want to manually control the history
    const { user } = render(_jsx(MemoryRouter, { initialEntries: ['/', '/some/bad/route'], children: _jsx(TestApp, {}) }));
    // verify navigation to "no match" route
    expect(screen.getByText(/404 page/i)).toBeInTheDocument();
    // go back using the UI your app provides
    await user.click(screen.getByRole('button', { name: /back/i }));
    expect(screen.getByText(/Home Page/i)).toBeInTheDocument();
});
//# sourceMappingURL=react-router.test.js.map