import { jsx as _jsx } from "react/jsx-runtime";
import { render, screen } from '..';
const TestEl = () => (_jsx("div", { children: _jsx("span", { children: "Test Content" }) }));
test('Eslint: testing-library/no-container', async () => {
    // > Avoid destructuring queries from `render` result, use `screen.queryByText` instead
    const { container } = render(_jsx(TestEl, {}));
    // > Avoid using container methods. Prefer using the methods from Testing Library, such as "getByRole()" testing-library/no-container
    // > Avoid direct Node access. Prefer using the methods from Testing Library. testing-library/no-node-access
    // https://github.com/testing-library/eslint-plugin-testing-library/blob/main/docs/rules/no-container.md
    // eslint-disable-next-line
    const el = container.querySelector('span');
    expect(el).toBeInTheDocument();
});
test('Eslint: testing-library/no-debugging-utils)', async () => {
    render(_jsx(TestEl, {}));
    const el = screen.queryByText('Test Content');
    // > Unexpected debug statement. testing-library/no-debugging-utils
    // https://github.com/testing-library/eslint-plugin-testing-library/blob/main/docs/rules/no-debugging-utils.md
    // screen.debug();
    // screen.logTestingPlaygroundURL()
    expect(el).toBeInTheDocument();
});
/**
 * https://kentcdodds.com/blog/common-mistakes-with-react-testing-library#using-the-wrong-assertion
 */
test('Prefer jest-dom to generic assertions', async () => {
    const TestButton = () => _jsx("button", { children: "Test Button" });
    render(_jsx(TestButton, {}));
    const button = screen.getByRole('button', { name: /test button/i });
    // we're wrapping these tests in try/catch because we expect theme to fail!
    // uncomment the console.log if you want to see the actual error
    try {
        // @ts-expect-error Property 'disabled' does not exist on type 'HTMLElement'
        expect(button.disabled).toBe(true);
    }
    catch (error) {
        // ❌ unhelpful: "Expected false to be true"
        // console.log(error);
    }
    try {
        expect(button).toBeDisabled();
    }
    catch (error) {
        // ✅ ideal: "Received element is not disabled: <button />"
        // console.log(error);
    }
});
//# sourceMappingURL=test-harness.test.js.map