// importing `* as ...` so we can use `vi.spyOn(module, 'exportedMember')` later
import * as exampleModuleNotMocked from './exampleModuleNotMocked';
const { default: defaultFn, doDecrement, doIncrement } = exampleModuleNotMocked;
vi.mock('./exampleModuleNotMocked', async (importOriginal) => {
    const mod = await importOriginal();
    return {
        /*
        This doesn't mock the originals as expected
    
        keys: [ 'namedExport', 'default' ]
        [Object: null prototype] [Module] { namedExport: [Getter], default: [Function (anonymous)] }
        */
        ...mod,
        doIncrement: vi.fn().mockImplementation((arg) => arg),
        default: vi.fn(),
    };
});
test('can mock a local function', async () => {
    // https://vitest.dev/api/mock.html#mockreturnvalue
    // const mock = vi.fn().mockReturnValue(42);
    // https://vitest.dev/api/mock.html#mockimplementation
    const mock = vi.fn().mockImplementation(() => 42);
    // this is unexpected:
    // expected [Function spy] to deeply equal true
    expect(mock()).toEqual(42);
    expect(mock).toBeCalledTimes(1);
});
test('spyOn calls through to the original implemenation', async () => {
    // https://vitest.dev/api/vi.html#vi-spyon
    vi.spyOn(exampleModuleNotMocked, 'notMocked');
    expect(exampleModuleNotMocked.notMocked()).toEqual(true);
    expect(exampleModuleNotMocked.notMocked).toBeCalledTimes(1);
});
test('can spyOn a function and augment the implementation', async () => {
    // https://vitest.dev/guide/migration.html#migrating-from-jest #Importing the original of a mocked package
    const { notMocked } = await vi.importActual('./exampleModuleNotMocked');
    // https://vitest.dev/api/vi.html#vi-spyon
    vi.spyOn(exampleModuleNotMocked, 'notMocked').mockImplementation(() => {
        // console.log('I can log here, for instance')
        return notMocked();
    });
    expect(exampleModuleNotMocked.notMocked()).toEqual(true);
    expect(exampleModuleNotMocked.notMocked).toBeCalledTimes(1);
});
// FIXME
test.skip('can mock a fn called directly from a module', async () => {
    // our mocked function returns it's input without incrementing
    expect(doIncrement(42)).toEqual(42);
    expect(doIncrement).toBeCalledTimes(1);
});
// FIXME
test.skip('can call an automocked fn', async () => {
    // our mocked function returns it's input without incrementing
    expect(doDecrement(42)).toEqual(undefined);
    expect(doDecrement).toBeCalledTimes(1);
});
// FIXME
test.skip('can mock a default export', async () => {
    expect(defaultFn()).toEqual(undefined);
    expect(defaultFn).toBeCalledTimes(1);
});
//# sourceMappingURL=vitest-mocking-inline.test.js.map