import '@testing-library/jest-dom';
/**
 * Mocked to prevent a JSDom error triggered by testing react-router:
 *
 * > Error: Not implemented: window.scrollTo
 *
 * https://stackoverflow.com/questions/57311971/error-not-implemented-window-scrollto-how-do-we-remove-this-error-from-jest-t
 *
 * You can check that this has been called:
 * ```tsx
 * expect(window.scrollTo).toHaveBeenCalled();
 * ```
 *
 * https://vitest.dev/api/mock.html#mockimplementation
 */
export const scrollToMock = vi.fn().mockImplementation(() => {
    // logging in here is preferrable to before every test file (beforeAll), and never logging
    console.log('[window.scrollTo] mocked to prevent "Error: Not implemented: window.scrollTo"');
});
Object.defineProperty(window, 'scrollTo', {
    value: scrollToMock,
    writable: true,
});
/**
 * Mock for window.matchMedia, preventing:
 *
 * > TypeError: win.matchMedia is not a function
 */
Object.defineProperty(window, 'matchMedia', {
    writable: true,
    value: vi.fn().mockImplementation((query) => ({
        matches: false,
        media: query,
        onchange: null,
        addListener: vi.fn(),
        removeListener: vi.fn(),
        addEventListener: vi.fn(),
        removeEventListener: vi.fn(),
        dispatchEvent: vi.fn(),
    })),
});
//# sourceMappingURL=setup.js.map