import { cardAnatomy } from '@chakra-ui/anatomy';
import { createMultiStyleConfigHelpers } from '@chakra-ui/styled-system';
const { definePartsStyle, defineMultiStyleConfig } = createMultiStyleConfigHelpers(cardAnatomy.keys);
const baseStyle = definePartsStyle({
    container: {
        backgroundColor: 'white',
    },
});
//TODO figure out why we can't use shorthand border definitions with color tokens
const formCard = definePartsStyle({
    container: {
        borderWidth: '1px',
        borderStyle: 'solid',
        borderColor: 'gray.300',
        borderRadius: 'base',
    },
});
const monthcard = definePartsStyle({
    container: {
        boxShadow: 'base',
        border: 'solid 1px #eaedf3',
        padding: 2,
        borderRadius: '4px',
        minHeight: '205px',
        minWidth: '177px',
    },
    header: {
        padding: 0,
        paddingTop: 0.5,
        paddingBottom: 1,
        textAlign: 'center',
        fontSize: '13px',
        fontWeight: '500',
        borderBottom: '1px solid #eceeee',
    },
    body: {
        marginTop: 5,
        padding: 0,
    },
});
const eventcard = definePartsStyle({
    container: {
        boxShadow: 'base',
        border: 'solid 1px #eaedf3',
        borderTop: 'solid 6px #eaedf3',
        padding: 3,
        borderRadius: '4px',
        marginBottom: 3,
        minHeight: 36,
        _hover: {
            cursor: 'pointer',
        },
    },
    header: {
        padding: 0,
        fontSize: '10px',
        fontWeight: '500',
        color: '#87929b',
        textTransform: 'uppercase',
    },
    body: {
        marginTop: 2,
        padding: 0,
        fontWeight: '500',
        color: '#1c1e2a',
        fontSize: '12',
    },
    footer: {
        padding: 0,
        paddingTop: 5,
        fontSize: '12px',
        color: '#9b9b9b',
    },
});
const eventcard_loreandculture = definePartsStyle((props) => ({
    ...props.theme.components.Card.variants.eventcard,
    container: {
        ...props.theme.components.Card.variants.eventcard.container,
        borderTop: 'solid 10px #f6ad55',
    },
}));
const eventcard_meeting = definePartsStyle((props) => ({
    ...props.theme.components.Card.variants.eventcard,
    container: {
        ...props.theme.components.Card.variants.eventcard.container,
        borderTop: 'solid 10px #d53f8c',
    },
}));
const eventcard_communication = definePartsStyle((props) => ({
    ...props.theme.components.Card.variants.eventcard,
    container: {
        ...props.theme.components.Card.variants.eventcard.container,
        borderTop: 'solid 10px #319795',
    },
}));
const eventcard_funeral = definePartsStyle((props) => ({
    ...props.theme.components.Card.variants.eventcard,
    container: {
        ...props.theme.components.Card.variants.eventcard.container,
        borderTop: 'solid 10px #718096',
    },
}));
/**
 * @see https://chakra-ui.com/docs/components/card/usage
 * @see https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/theme/src/components/card.ts
 */
export const customCardTheme = defineMultiStyleConfig({
    baseStyle,
    variants: {
        formCard,
        monthcard,
        eventcard,
        eventcard_loreandculture,
        eventcard_meeting,
        eventcard_communication,
        eventcard_funeral,
    },
    defaultProps: {
    // Note: 'elevated' is the default
    },
});
//# sourceMappingURL=Card.js.map