import { defineStyle, defineStyleConfig } from '@chakra-ui/styled-system';
const baseStyle = {
// Rather than set a color in here, consider setting semanticColors['chakra-body-text']
};
// only used on login pages
const heading1Variant = {
    fontSize: '28px',
    fontWeight: '700',
    lineHeight: '24px',
    letterSpacing: '-0.23px',
    color: '#383838',
    marginBottom: '25px', // FIXME prefer token
};
const pageHeadingVariant = {
    fontSize: '20px',
    fontWeight: '500',
    color: '#212529', // FIXME theme token
};
/**
 * Note that `fontSize` is defined as responsive values for larger sizes
 *
 * https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/theme/src/components/heading.ts
 */
const sizes = {
    '4xl': defineStyle({
        fontSize: ['6xl', null, '7xl'],
        lineHeight: 1,
    }),
    '3xl': defineStyle({
        fontSize: ['5xl', null, '6xl'],
        lineHeight: 1,
    }),
    '2xl': defineStyle({
        fontSize: ['4xl', null, '5xl'],
        lineHeight: [1.2, null, 1],
    }),
    xl: defineStyle({
        fontSize: ['3xl', null, '4xl'],
        lineHeight: [1.33, null, 1.2],
    }),
    lg: defineStyle({
        fontSize: ['2xl', null, '3xl'],
        lineHeight: [1.33, null, 1.2],
    }),
    md: defineStyle({
        fontSize: 'xl',
        lineHeight: 1.2,
    }),
    sm: defineStyle({
        fontSize: 'md',
        lineHeight: 1.2,
    }),
    xs: defineStyle({
        fontSize: 'sm',
        lineHeight: 1.2,
    }),
};
/**
 * Consider whether the stying we need can be accomplished via theme/foundations/typography.
 *
 * @see https://chakra-ui.com/docs/components/heading
 * @see https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/theme/src/components/heading.ts
 * @see https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/layout/src/heading.tsx
 */
export const headingTheme = defineStyleConfig({
    baseStyle,
    sizes,
    variants: {
        heading1: heading1Variant,
        pageHeading: pageHeadingVariant,
    },
    defaultProps: {
    // size: 'xl',
    // variant: 'custom',
    // colorScheme: 'brand',
    },
});
//# sourceMappingURL=Heading.js.map