import { tabsAnatomy } from '@chakra-ui/anatomy';
import { createMultiStyleConfigHelpers } from '@chakra-ui/styled-system';
import { mode } from '@chakra-ui/theme-tools';
const { definePartsStyle, defineMultiStyleConfig } = createMultiStyleConfigHelpers(tabsAnatomy.keys);
const baseStyle = definePartsStyle({});
const sizes = {
    cardAttachment: definePartsStyle({
        tab: {
            fontSize: 'xs',
            py: '2',
            px: '5',
        },
    }),
};
const cardAttachmentVariant = definePartsStyle((props) => {
    const { colorScheme: c } = props;
    return {
        root: {
            marginBottom: '-1px',
        },
        tablist: {
            marginBottom: '-1px',
        },
        tab: {
            textTransform: 'uppercase',
            fontWeight: 'bold',
            marginRight: '4px',
            borderWidth: '1px',
            borderColor: `${c}.300`,
            bg: mode(`white`, `${c}.600`)(props),
            borderTopRadius: 'md',
            borderBottom: 'none',
            color: mode(`link.500`, `${c}.300`)(props),
            _selected: {
                bg: mode('white', 'gray.800')(props),
                color: mode(`inherit`, `${c}.300`)(props),
            },
            _disabled: {
                bg: mode(`white`, `${c}.600`)(props),
                color: mode(`${c}.300`, `${c}.300`)(props),
                opacity: 1,
            },
        },
    };
});
/**
 * @see https://chakra-ui.com/docs/components/tabs
 * @see https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/theme/src/components/tabs.ts
 */
export const tabsTheme = defineMultiStyleConfig({
    baseStyle,
    variants: {
        cardAttachment: cardAttachmentVariant,
    },
    sizes,
});
//# sourceMappingURL=Tabs.js.map