import { defineStyleConfig } from '@chakra-ui/styled-system';
const baseStyle = {
    // Rather than set a color in here, consider setting semanticColors['chakra-body-text']
    color: '#383838', // FIXME prefer changing via semanticColors
};
const warningVariant = {
    textTransform: 'uppercase',
    fontWeight: 'bold',
    fontSize: '13px', // FIXME theme scale
};
const defaultVariant = {
    fontSize: '13px',
    marginTop: '0px', // FIXME remove margins
};
const infoVariant = {
    fontSize: '11px',
    lineHeight: '14px',
    letterSpacing: '0',
};
const focusTextVariant = {
    color: '#212529',
    fontWeight: '500',
};
const brandingTextVariant = {
    fontSize: '29px',
    lineHeight: 'none',
    letterSpacing: '-1px',
};
/**
 * Consider whether the stying we need can be accomplished via theme/foundations/typography.
 *
 * Eg, rather than setting fontSizes in variants,  create `sizes`
 *
 * Note, there is no theme for `Text` defined in the base package - it gets its sizes from... TODO where
 *
 * > The text styles functionality in Chakra makes it easy to repeatably apply a
 * > collection of text properties (like line height and size) to any component
 * > https://chakra-ui.com/docs/styled-system/text-and-layer-styles#text-styles
 *
 * @see https://chakra-ui.com/docs/components/text
 * @see https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/layout/src/text.tsx
 */
export const textTheme = defineStyleConfig({
    baseStyle,
    /**
     * Rather than creating variants for Text, consider whether a textStyle would be more useful
     *
     * ```jsx
     * <Text textStyle="shared">Shared here</Text>
     * <Box textStyle="shared">...and here</Box>
     * ```
     */
    variants: {
        warning: warningVariant,
        default: defaultVariant,
        info: infoVariant,
        focusText: focusTextVariant,
        brandingText: brandingTextVariant,
    },
    defaultProps: {
        // size: 'md',
        variant: 'default', // FIXME change via typography settings instead
        // colorScheme: 'gray',
    },
});
//# sourceMappingURL=Text.js.map