/**
 * > Chakra UI supports responsive styles out of the box. Instead of manually
 * > adding @media queries and adding nested styles throughout your code, Chakra
 * > UI allows you to provide object and array values to add mobile-first
 * > responsive styles.
 * > @see https://chakra-ui.com/docs/styled-system/responsive-styles
 *
 * Eg, these are equivalent:
 * ```jsx
 * // array notation
 * <Box fontWeight={[300, 400, 500]} />
 *
 * // object notation
 * <Box fontWeight={{ base: 300, sm: 400, md: 500 }} />
 * ```
 *
 * You can use style tokens from `sizing` such as 'max', 'min', 'full', 'sm', etc:
 * @see https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/theme/src/foundations/sizes.ts
 *
 * Defaults: https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/theme/src/foundations/breakpoints.ts
 */
export const breakpoints = {
    base: '0em',
    sm: '30em',
    md: '48em',
    lg: '62em',
    xl: '80em',
    '2xl': '96em',
    hd: '120em', // 1920
    // see semantic tokens for our defaults, so related values can get co-located
};
//# sourceMappingURL=breakpoints.js.map