import { type Colors, type Pseudos, type SemanticValue } from '@chakra-ui/react';
/**
 * Type extracted from `ChakraTheme['semanticTokens']`
 *
 * > A semantic token value can be a string | SemanticValue. The string value is
 * > used as reference to another token in the same scale
 * @see https://chakra-ui.com/docs/styled-system/semantic-tokens#token-references
 */
type SemanticColorTokens = Record<string, SemanticValue<keyof Pseudos>>;
/**
 * Colour roles for use in components, which are merged into semanticTokens.
 *
 * > Chakra UI supports conditional semantic tokens for every scale (colors,
 * > font sizes, etc). This allows to change the value of a token depending on
 * > the environment, like dark mode, direction and other CSS selectors.
 * > @see https://chakra-ui.com/docs/styled-system/semantic-tokens
 *
 * > The object notation SemanticValue allows to define the default value and
 * > conditional keys. The condition can be one of chakra pseudo selectors or a
 * > custom CSS selector. Try _dark, _light, _rtl, _ltr and _mediaReduceMotion.
 * > @see https://chakra-ui.com/docs/styled-system/semantic-tokens#conditional-tokens
 *
 * Default values:
 * @see https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/theme/src/semantic-tokens.ts
 */
export declare const semanticColors: SemanticColorTokens;
/**
 * Raw colours available in the theme (Note: this copy of defaults overwrites the
 * baseTheme, omitting social colours).
 *
 * In general, prefer using a color _role_ from `palette` ^
 * in your components, eg: 'primary', 'secondary', 'highlight'.
 *
 * > By default these colors can be referenced by the `color`, `borderColor`,
 * > `backgroundColor`, `fill`, `stroke`, styles.
 * >
 * > We recommend adding a palette that ranges from 50 to 900. Tools like Themera,
 * > Smart Swatch, Coolors or Palx are available to generate these palettes.
 * > @see https://chakra-ui.com/docs/styled-system/theme#colors
 *
 * @see https://chakra-ui.com/docs/styled-system/customize-theme#customizing-theme-tokens
 */
export declare const colors: Colors;
export {};
