/**
 * > Layer Styles allow you to save a combination of styling attributes to
 * > re-use in other components. Once created, pass the layerStyle prop to
 * > any component and chakra will resolve the styles accordingly.
 * > ...
 * > Layer Styles will not override variant styling.
 *
 * @see https://chakra-ui.com/docs/styled-system/text-and-layer-styles#layer-styles
 *
 * ```jsx
 * <Box layerStyle="shared">...and here</Box>
 * <Box layerStyle={['shared', 'anotherLayerStyle']}>mutltiple layerStyles</Box>
 * ```
 */
export declare const layerStyles: {
    scrollbars: {
        '&::-webkit-scrollbar': {
            width: string;
            background: string;
        };
        '&::-webkit-scrollbar-thumb': {
            backgroundColor: string;
        };
    };
    /**
     * REVIEW which do we prefer:
     *
     * ```tsx
     * <Stack layerStyle="stackDefault" {...props} />
     * <Stack spacing="comfortable" {...props} />
     * ```
     */
    stackDefault: {
        gap: string;
    };
    /** commonly used for clickable inputAddons */
    hoverPointer: {
        _hover: {
            cursor: string;
        };
    };
};
