import { semanticColors } from './semanticColors';
/**
 * The keys of semanticTokens mirrors the keys of the theme itself
 *
 * Theme tokens inside semanticToken definitions will be resolved:
 *
 * ```ts
 * space: { gutter: 6 } // '6' resolves to '1.5rem'
 * ```
 *
 * @see https://chakra-ui.com/docs/styled-system/semantic-tokens
 * @see https://github.com/chakra-ui/chakra-ui/blob/main/packages/components/theme/src/theme.types.ts#L123
 */
export const semanticTokens = {
    colors: semanticColors,
    borders: {
    // photoFrameExample: "8px groove grey",
    },
    sizes: {
        // see also `<Container variant="dekstopLayout" />`
        // this is the target element width from the design (without gutters)
        default: '1280px',
        defaultPlusGutter: 'calc(var(--chakra-sizes-default) + var(--chakra-space-gutter) * 2)',
        rightColumnWidth: '300px',
    },
    space: {
        gutter: '6',
        // narrow?
        comfortable: '6', // like gmail, etc?
        // wide?
    },
};
//# sourceMappingURL=semanticTokens.js.map