/**
 * > The text styles functionality in Chakra makes it easy to repeatably
 * > apply a collection of text properties (like line height and size) to
 * > any component.
 *
 * @see https://chakra-ui.com/docs/styled-system/text-and-layer-styles#text-styles
 *
 * Rather than creating variants for Text, consider whether a textStyle would be more useful
 *
 * ```jsx
 * <Text textStyle="shared">Shared here</Text>
 * <Box textStyle="shared">...and here</Box>
 * <Box textStyle={['shared', 'anotherTextStyle']}>mutltiple textStyles</Box>
 * ```
 *
 * Styles derived from @see https://app.zeplin.io/project/63db299855f49c3c314dbf9c/styleguide/textstyles?tsid=63db2a7f1210f1496ef76c77
 */
export declare const textStyles: {
    displayHeading: {
        fontSize: string;
        fontWeight: string;
        lineHeight: number;
        letterSpacing: string;
        color: string;
    };
    displayBrand: {
        fontSize: string;
        fontWeight: number;
        lineHeight: number;
    };
    h1: {
        fontSize: string;
        fontWeight: number;
        lineHeight: number;
    };
    h2: {
        fontSize: string;
        fontWeight: number;
        lineHeight: number;
    };
    h3: {
        fontSize: string;
        fontWeight: number;
        lineHeight: number;
    };
    h4: {
        fontSize: string;
        fontWeight: string;
        lineHeight: number;
    };
    p: {};
    storyBookDemo1: {
        color: string;
    };
    storyBookDemo2: {
        fontSize: string;
    };
};
